@@ -1,4 +1,4 @@
-library(httptest)
+library(testthat)
 library(portalr)
 
 test_check("portalr")
