@@ -11,6 +11,12 @@ test_that("download_observations and check_for_newer_data work", {
     })
     unlink(file.path(portal_data_path, "PortalData"), recursive = TRUE)
 
+    expect_message(download_observations(portal_data_path))
+    expect_message(download_observations(portal_data_path))
+    unlink(file.path(portal_data_path, "PortalData"), recursive = TRUE)
+
+
+
     expect_error(download_observations(portal_data_path, version = "1.6.0"), NA)
     expect_true(check_for_newer_data(portal_data_path))
     unlink(file.path(portal_data_path, "PortalData"), recursive = TRUE)
@@ -19,7 +25,8 @@ test_that("download_observations and check_for_newer_data work", {
     expect_error(download_observations(portal_data_path, version = "1.5.9"))
     expect_error(download_observations(portal_data_path, version = "1.000.0"))
 
-    expect_error(download_observations(portal_data_path, from_zenodo = TRUE, timeout = 300), NA)
+    expect_error(download_observations(portal_data_path, source = "zenodo", timeout = 300), NA)
+    expect_error(download_observations(portal_data_path, source = "xxx"), "`source` must be either 'zenodo' or 'github'")
     expect_false(check_for_newer_data(portal_data_path))
     #unlink(file.path(portal_data_path, "PortalData"), recursive = TRUE)
 
